@@ -1,5 +1,3 @@
-import signal
-import logging
 import unittest
 
 import redis
@@ -11,6 +9,7 @@ from kuyruk.test import tasks
 from kuyruk.test.integration.util import *
 from kuyruk.connection import Channel
 
+
 Channel.SKIP_REDECLARE_QUEUE = False
 
 logger = logging.getLogger(__name__)
